==> tdesktop-4.8.4-full.tar.gz: tdesktop-4.8.4-full/Telegram/ThirdParty/range-v3/doc/gh-pages/dir_b00b1d9d00cc44a1bf5374fbcb141bf4.js <==
var dir_b00b1d9d00cc44a1bf5374fbcb141bf4 =
[
    [ "adaptor.hpp", "adaptor_8hpp.html", "adaptor_8hpp" ],
    [ "addressof.hpp", "view_2addressof_8hpp.html", [
      [ "addressof_fn", "structranges_1_1views_1_1addressof__fn.html", "structranges_1_1views_1_1addressof__fn" ]
    ] ],
    [ "adjacent_filter.hpp", "adjacent__filter_8hpp.html", "adjacent__filter_8hpp" ],
    [ "adjacent_remove_if.hpp", "view_2adjacent__remove__if_8hpp.html", "view_2adjacent__remove__if_8hpp" ],
    [ "all.hpp", "view_2all_8hpp.html", "view_2all_8hpp" ],
    [ "any_view.hpp", "any__view_8hpp.html", "any__view_8hpp" ],
    [ "c_str.hpp", "c__str_8hpp.html", null ],
    [ "cache1.hpp", "cache1_8hpp.html", "cache1_8hpp" ],
    [ "cartesian_product.hpp", "cartesian__product_8hpp.html", "cartesian__product_8hpp" ],
    [ "chunk.hpp", "chunk_8hpp.html", "chunk_8hpp" ],
    [ "common.hpp", "common_8hpp.html", "common_8hpp" ],
    [ "concat.hpp", "concat_8hpp.html", "concat_8hpp" ],
    [ "const.hpp", "const_8hpp.html", "const_8hpp" ],
    [ "counted.hpp", "counted_8hpp.html", "counted_8hpp" ],
    [ "cycle.hpp", "cycle_8hpp.html", "cycle_8hpp" ],
    [ "delimit.hpp", "delimit_8hpp.html", "delimit_8hpp" ],
    [ "drop.hpp", "view_2drop_8hpp.html", "view_2drop_8hpp" ],
    [ "drop_exactly.hpp", "drop__exactly_8hpp.html", "drop__exactly_8hpp" ],
    [ "drop_last.hpp", "drop__last_8hpp.html", "drop__last_8hpp" ],
    [ "drop_while.hpp", "view_2drop__while_8hpp.html", "view_2drop__while_8hpp" ],
    [ "empty.hpp", "empty_8hpp.html", "empty_8hpp" ],
    [ "enumerate.hpp", "enumerate_8hpp.html", [
      [ "enumerate_fn", "structranges_1_1views_1_1enumerate__fn.html", "structranges_1_1views_1_1enumerate__fn" ]
    ] ],
    [ "exclusive_scan.hpp", "exclusive__scan_8hpp.html", "exclusive__scan_8hpp" ],
    [ "facade.hpp", "facade_8hpp.html", [
      [ "view_as_cursor", "structranges_1_1view__facade_1_1view__as__cursor.html", "structranges_1_1view__facade_1_1view__as__cursor" ]
    ] ],
    [ "filter.hpp", "filter_8hpp.html", "filter_8hpp" ],
    [ "for_each.hpp", "view_2for__each_8hpp.html", [
      [ "for_each_base_fn", "structranges_1_1views_1_1for__each__base__fn.html", "structranges_1_1views_1_1for__each__base__fn" ],
      [ "for_each_fn", "structranges_1_1views_1_1for__each__fn.html", "structranges_1_1views_1_1for__each__fn" ]
    ] ],
    [ "generate.hpp", "view_2generate_8hpp.html", null ],
    [ "generate_n.hpp", "view_2generate__n_8hpp.html", [
      [ "generate_n_fn", "structranges_1_1views_1_1generate__n__fn.html", "structranges_1_1views_1_1generate__n__fn" ]
    ] ],
    [ "getlines.hpp", "getlines_8hpp.html", "getlines_8hpp" ],
    [ "group_by.hpp", "group__by_8hpp.html", "group__by_8hpp" ],
    [ "indices.hpp", "indices_8hpp.html", [
      [ "closed_indices_fn", "structranges_1_1views_1_1closed__indices__fn.html", "structranges_1_1views_1_1closed__indices__fn" ],
      [ "indices_fn", "structranges_1_1views_1_1indices__fn.html", "structranges_1_1views_1_1indices__fn" ]
    ] ],
    [ "indirect.hpp", "view_2indirect_8hpp.html", "view_2indirect_8hpp" ],
    [ "interface.hpp", "interface_8hpp.html", "interface_8hpp" ],
    [ "intersperse.hpp", "intersperse_8hpp.html", "intersperse_8hpp" ],
    [ "iota.hpp", "view_2iota_8hpp.html", "view_2iota_8hpp" ],
    [ "istream.hpp", "istream_8hpp.html", "istream_8hpp" ],
    [ "join.hpp", "view_2join_8hpp.html", "view_2join_8hpp" ],
    [ "linear_distribute.hpp", "linear__distribute_8hpp.html", null ],
    [ "map.hpp", "map_8hpp.html", "map_8hpp" ],
    [ "move.hpp", "view_2move_8hpp.html", "view_2move_8hpp" ],
    [ "partial_sum.hpp", "view_2partial__sum_8hpp.html", "view_2partial__sum_8hpp" ],
    [ "ref.hpp", "ref_8hpp.html", "ref_8hpp" ],
    [ "remove.hpp", "view_2remove_8hpp.html", [
      [ "remove_base_fn", "structranges_1_1views_1_1remove__base__fn.html", "structranges_1_1views_1_1remove__base__fn" ],
      [ "remove_bind_fn", "structranges_1_1views_1_1remove__bind__fn.html", "structranges_1_1views_1_1remove__bind__fn" ],
      [ "remove_fn", "structranges_1_1views_1_1remove__fn.html", "structranges_1_1views_1_1remove__fn" ]
    ] ],
    [ "remove_if.hpp", "view_2remove__if_8hpp.html", "view_2remove__if_8hpp" ],
    [ "repeat.hpp", "repeat_8hpp.html", [
      [ "repeat_fn", "structranges_1_1views_1_1repeat__fn.html", "structranges_1_1views_1_1repeat__fn" ]
    ] ],
    [ "repeat_n.hpp", "repeat__n_8hpp.html", [
      [ "repeat_n_fn", "structranges_1_1views_1_1repeat__n__fn.html", "structranges_1_1views_1_1repeat__n__fn" ]
    ] ],
    [ "replace.hpp", "view_2replace_8hpp.html", [
      [ "replace_base_fn", "structranges_1_1views_1_1replace__base__fn.html", "structranges_1_1views_1_1replace__base__fn" ],
      [ "replace_fn", "structranges_1_1views_1_1replace__fn.html", "structranges_1_1views_1_1replace__fn" ]
    ] ],
    [ "replace_if.hpp", "view_2replace__if_8hpp.html", [
      [ "replace_if_base_fn", "structranges_1_1views_1_1replace__if__base__fn.html", "structranges_1_1views_1_1replace__if__base__fn" ],
      [ "replace_if_fn", "structranges_1_1views_1_1replace__if__fn.html", "structranges_1_1views_1_1replace__if__fn" ]
    ] ],
    [ "reverse.hpp", "view_2reverse_8hpp.html", "view_2reverse_8hpp" ],
    [ "sample.hpp", "view_2sample_8hpp.html", "view_2sample_8hpp" ],
    [ "set_algorithm.hpp", "view_2set__algorithm_8hpp.html", "view_2set__algorithm_8hpp" ],
    [ "single.hpp", "single_8hpp.html", "single_8hpp" ],
    [ "slice.hpp", "view_2slice_8hpp.html", "view_2slice_8hpp" ],
    [ "sliding.hpp", "sliding_8hpp.html", "sliding_8hpp" ],
    [ "span.hpp", "span_8hpp.html", "span_8hpp" ],
    [ "split.hpp", "view_2split_8hpp.html", "view_2split_8hpp" ],
    [ "split_when.hpp", "view_2split__when_8hpp.html", "view_2split__when_8hpp" ],
    [ "stride.hpp", "view_2stride_8hpp.html", "view_2stride_8hpp" ],
    [ "subrange.hpp", "subrange_8hpp.html", "subrange_8hpp" ],
    [ "tail.hpp", "tail_8hpp.html", "tail_8hpp" ],
    [ "take.hpp", "view_2take_8hpp.html", "view_2take_8hpp" ],
    [ "take_exactly.hpp", "take__exactly_8hpp.html", [
      [ "take_exactly_base_fn", "structranges_1_1views_1_1take__exactly__base__fn.html", "structranges_1_1views_1_1take__exactly__base__fn" ],
      [ "take_exactly_fn", "structranges_1_1views_1_1take__exactly__fn.html", "structranges_1_1views_1_1take__exactly__fn" ]
    ] ],
    [ "take_last.hpp", "take__last_8hpp.html", [
      [ "take_last_base_fn", "structranges_1_1views_1_1take__last__base__fn.html", "structranges_1_1views_1_1take__last__base__fn" ],
      [ "take_last_fn", "structranges_1_1views_1_1take__last__fn.html", "structranges_1_1views_1_1take__last__fn" ]
    ] ],
    [ "take_while.hpp", "view_2take__while_8hpp.html", "view_2take__while_8hpp" ],
    [ "tokenize.hpp", "tokenize_8hpp.html", "tokenize_8hpp" ],
    [ "transform.hpp", "view_2transform_8hpp.html", "view_2transform_8hpp" ],
    [ "trim.hpp", "trim_8hpp.html", "trim_8hpp" ],
    [ "unique.hpp", "view_2unique_8hpp.html", [
      [ "unique_base_fn", "structranges_1_1views_1_1unique__base__fn.html", "structranges_1_1views_1_1unique__base__fn" ],
      [ "unique_fn", "structranges_1_1views_1_1unique__fn.html", "structranges_1_1views_1_1unique__fn" ]
    ] ],
    [ "view.hpp", "view_2view_8hpp.html", "view_2view_8hpp" ],
    [ "zip.hpp", "zip_8hpp.html", "zip_8hpp" ],
    [ "zip_with.hpp", "zip__with_8hpp.html", "zip__with_8hpp" ]
];

==> tdesktop-5.8.3-full.tar.gz: tdesktop-5.8.3-full/Telegram/ThirdParty/range-v3/doc/gh-pages/dir_b00b1d9d00cc44a1bf5374fbcb141bf4.js <==
var dir_b00b1d9d00cc44a1bf5374fbcb141bf4 =
[
    [ "adaptor.hpp", "adaptor_8hpp.html", null ],
    [ "addressof.hpp", "view_2addressof_8hpp.html", "view_2addressof_8hpp" ],
    [ "adjacent_filter.hpp", "adjacent__filter_8hpp.html", "adjacent__filter_8hpp" ],
    [ "adjacent_remove_if.hpp", "view_2adjacent__remove__if_8hpp.html", "view_2adjacent__remove__if_8hpp" ],
    [ "all.hpp", "view_2all_8hpp.html", "view_2all_8hpp" ],
    [ "any_view.hpp", "any__view_8hpp.html", "any__view_8hpp" ],
    [ "c_str.hpp", "c__str_8hpp.html", null ],
    [ "cache1.hpp", "cache1_8hpp.html", "cache1_8hpp" ],
    [ "cartesian_product.hpp", "cartesian__product_8hpp.html", "cartesian__product_8hpp" ],
    [ "chunk.hpp", "chunk_8hpp.html", "chunk_8hpp" ],
    [ "chunk_by.hpp", "chunk__by_8hpp.html", "chunk__by_8hpp" ],
    [ "common.hpp", "common_8hpp.html", "common_8hpp" ],
    [ "concat.hpp", "concat_8hpp.html", "concat_8hpp" ],
    [ "const.hpp", "const_8hpp.html", "const_8hpp" ],
    [ "counted.hpp", "counted_8hpp.html", "counted_8hpp" ],
    [ "cycle.hpp", "cycle_8hpp.html", "cycle_8hpp" ],
    [ "delimit.hpp", "delimit_8hpp.html", "delimit_8hpp" ],
    [ "drop.hpp", "view_2drop_8hpp.html", "view_2drop_8hpp" ],
    [ "drop_exactly.hpp", "drop__exactly_8hpp.html", "drop__exactly_8hpp" ],
    [ "drop_last.hpp", "drop__last_8hpp.html", "drop__last_8hpp" ],
    [ "drop_while.hpp", "view_2drop__while_8hpp.html", "view_2drop__while_8hpp" ],
    [ "empty.hpp", "empty_8hpp.html", null ],
    [ "enumerate.hpp", "enumerate_8hpp.html", "enumerate_8hpp" ],
    [ "exclusive_scan.hpp", "exclusive__scan_8hpp.html", "exclusive__scan_8hpp" ],
    [ "facade.hpp", "facade_8hpp.html", "facade_8hpp" ],
    [ "filter.hpp", "filter_8hpp.html", "filter_8hpp" ],
    [ "for_each.hpp", "view_2for__each_8hpp.html", "view_2for__each_8hpp" ],
    [ "generate.hpp", "view_2generate_8hpp.html", null ],
    [ "generate_n.hpp", "view_2generate__n_8hpp.html", "view_2generate__n_8hpp" ],
    [ "getlines.hpp", "getlines_8hpp.html", null ],
    [ "group_by.hpp", "group__by_8hpp.html", "group__by_8hpp" ],
    [ "indices.hpp", "indices_8hpp.html", "indices_8hpp" ],
    [ "indirect.hpp", "view_2indirect_8hpp.html", null ],
    [ "interface.hpp", "interface_8hpp.html", null ],
    [ "intersperse.hpp", "intersperse_8hpp.html", null ],
    [ "iota.hpp", "view_2iota_8hpp.html", "view_2iota_8hpp" ],
    [ "istream.hpp", "istream_8hpp.html", null ],
    [ "join.hpp", "view_2join_8hpp.html", "view_2join_8hpp" ],
    [ "linear_distribute.hpp", "linear__distribute_8hpp.html", null ],
    [ "map.hpp", "map_8hpp.html", "map_8hpp" ],
    [ "move.hpp", "view_2move_8hpp.html", "view_2move_8hpp" ],
    [ "partial_sum.hpp", "view_2partial__sum_8hpp.html", "view_2partial__sum_8hpp" ],
    [ "ref.hpp", "ref_8hpp.html", null ],
    [ "remove.hpp", "view_2remove_8hpp.html", "view_2remove_8hpp" ],
    [ "remove_if.hpp", "view_2remove__if_8hpp.html", "view_2remove__if_8hpp" ],
    [ "repeat.hpp", "repeat_8hpp.html", "repeat_8hpp" ],
    [ "repeat_n.hpp", "repeat__n_8hpp.html", "repeat__n_8hpp" ],
    [ "replace.hpp", "view_2replace_8hpp.html", "view_2replace_8hpp" ],
    [ "replace_if.hpp", "view_2replace__if_8hpp.html", "view_2replace__if_8hpp" ],
    [ "reverse.hpp", "view_2reverse_8hpp.html", "view_2reverse_8hpp" ],
    [ "sample.hpp", "view_2sample_8hpp.html", "view_2sample_8hpp" ],
    [ "set_algorithm.hpp", "view_2set__algorithm_8hpp.html", "view_2set__algorithm_8hpp" ],
    [ "single.hpp", "single_8hpp.html", "single_8hpp" ],
    [ "slice.hpp", "view_2slice_8hpp.html", "view_2slice_8hpp" ],
    [ "sliding.hpp", "sliding_8hpp.html", "sliding_8hpp" ],
    [ "span.hpp", "span_8hpp.html", null ],
    [ "split.hpp", "view_2split_8hpp.html", "view_2split_8hpp" ],
    [ "split_when.hpp", "view_2split__when_8hpp.html", "view_2split__when_8hpp" ],
    [ "stride.hpp", "view_2stride_8hpp.html", "view_2stride_8hpp" ],
    [ "subrange.hpp", "subrange_8hpp.html", "subrange_8hpp" ],
    [ "tail.hpp", "tail_8hpp.html", "tail_8hpp" ],
    [ "take.hpp", "view_2take_8hpp.html", "view_2take_8hpp" ],
    [ "take_exactly.hpp", "take__exactly_8hpp.html", "take__exactly_8hpp" ],
    [ "take_last.hpp", "take__last_8hpp.html", "take__last_8hpp" ],
    [ "take_while.hpp", "view_2take__while_8hpp.html", "view_2take__while_8hpp" ],
    [ "tokenize.hpp", "tokenize_8hpp.html", "tokenize_8hpp" ],
    [ "transform.hpp", "view_2transform_8hpp.html", "view_2transform_8hpp" ],
    [ "trim.hpp", "trim_8hpp.html", "trim_8hpp" ],
    [ "unique.hpp", "view_2unique_8hpp.html", "view_2unique_8hpp" ],
    [ "view.hpp", "view_2view_8hpp.html", "view_2view_8hpp" ],
    [ "zip.hpp", "zip_8hpp.html", "zip_8hpp" ],
    [ "zip_with.hpp", "zip__with_8hpp.html", "zip__with_8hpp" ]
];
